use std::path::PathBuf;

use clap::Parser;

use radicle_ci_broker::db2::Db;

fn main() -> anyhow::Result<()> {
    let args = Args::parse();

    let db = Db::new(&args.filename)?;

    println!("start counting");

    loop {
        db.begin()?;

        let current = db.get_counter()?.unwrap_or(0);
        println!("current: {current}");
        if current >= args.goal {
            break;
        }

        let new = current + 1;
        if (new == 1 && db.create_counter(new).is_err()) || db.update_counter(new).is_err() {
            db.rollback()?;
        } else {
            db.commit()?;
            println!("INSERT {new}");
        }
    }
    Ok(())
}

#[derive(Parser)]
struct Args {
    filename: PathBuf,
    goal: i64,
}
